@@ -35,14 +35,15 @@ from sphinx.util.nodes import make_refnode
 
 from sphinxcontrib.chapeldomain.chapel import ChapelLexer
 
-VERSION = '0.0.23'
+VERSION = '0.0.24'
 
 
 # regex for parsing proc, iter, class, record, etc.
 chpl_sig_pattern = re.compile(
     r"""^ ((?:\w+\s+)*                             # opt: prefixes
            (?:proc|iter|class|record|operator)\s+  # must end with keyword
-           (?:type\s+|param\s+)?                   # opt: type or param method
+           (?:type\s+|param\s+|ref\s+)?            # opt: 'this' intent
+                                                   #  (type, param, ref)
           )?
           ([\w$.]*\.)?                             # class name(s)
           ([\w\+\-/\*$\<\=\>\!]+)  \s*             # function or method name
