@@ -457,6 +457,8 @@ class ChapelObjectTests(ChapelObjectTestCase):
             ('proc foo', 'proc '),
             ('inline proc foo', 'inline proc '),
             ('proc foo() ref', 'proc '),
+            ('proc ref foo() ref', 'proc ref '),
+            ('proc ref foo()', 'proc ref '),
             ('iter foo() ref', 'iter '),
             ('inline iter foo(x, y): int(32)', 'inline iter '),
             ('proc proc proc proc proc proc', 'proc proc proc proc proc '),
@@ -479,6 +481,8 @@ class ChapelObjectTests(ChapelObjectTestCase):
             ('proc foo', 'proc '),
             ('inline proc foo', 'inline proc '),
             ('proc foo() ref', 'proc '),
+            ('proc ref foo() ref', 'proc ref '),
+            ('proc ref foo()', 'proc ref '),
             ('iter foo() ref', 'iter '),
             ('inline iter foo(x, y): int(32)', 'inline iter '),
             ('iter iter iter iter iter iter', 'iter iter iter iter iter '),
